@@ -1,4 +1,6 @@
 use cosmwasm_std::StdError;
+use cw_utils::ThresholdError;
+
 use thiserror::Error;
 
 #[derive(Error, Debug, PartialEq)]
@@ -6,6 +8,9 @@ pub enum ContractError {
     #[error("{0}")]
     Std(#[from] StdError),
 
+    #[error("{0}")]
+    Threshold(#[from] ThresholdError),
+
     #[error("Required weight cannot be zero")]
     ZeroWeight {},
 
